@@ -1877,12 +1877,17 @@ class Provider(BaseProvider):
         self,
         tzinfo: Optional[TzInfo] = None,
         end_datetime: Optional[DateParseType] = None,
+        sep: str = "T",
+        timespec: str = "auto",
     ) -> str:
         """
+        Get a timestamp in ISO 8601 format (or one of its profiles).
         :param tzinfo: timezone, instance of datetime.tzinfo subclass
+        :param sep: separator between date and time, defaults to 'T'
+        :param timespec: format specifier for the time part, defaults to 'auto' - see datetime.isoformat() documentation
         :example: '2003-10-21T16:05:52+0000'
         """
-        return self.date_time(tzinfo, end_datetime=end_datetime).isoformat()
+        return self.date_time(tzinfo, end_datetime=end_datetime).isoformat(sep, timespec)
 
     def date(self, pattern: str = "%Y-%m-%d", end_datetime: Optional[DateParseType] = None) -> str:
         """
@@ -1978,7 +1983,7 @@ class Provider(BaseProvider):
             time_params = cls._parse_date_string(value)
             return datetime_to_timestamp(now + timedelta(**time_params))  # type: ignore
         if isinstance(value, int):
-            return datetime_to_timestamp(now + timedelta(value))
+            return value
         raise ParseError(f"Invalid format for date {value!r}")
 
     @classmethod
@@ -2406,11 +2411,11 @@ class Provider(BaseProvider):
     def year(self) -> str:
         return self.date("%Y")
 
-    def century(self) -> str:
+    def century(self, min_length: Optional[int] = None, max_length: Optional[int] = None) -> str:
         """
         :example: 'XVII'
         """
-        return self.random_element(self.centuries)
+        return self.random_element(self.centuries, min_length, max_length)
 
     def timezone(self) -> str:
         return self.generator.random.choice(self.random_element(self.countries)["timezones"])  # type: ignore
